# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/).


## [0.0.2] - 2022-07-11
### Fixed
- fixed badge for supported Python versions

## [0.0.1] - 2022-07-11
### Added
- initial package version
